@@ -1,4 +1,4 @@
-package Pcore::Redis v0.6.3;
+package Pcore::Redis v0.7.0;
 
 use Pcore -dist, -class;
 
@@ -16,6 +16,12 @@ sub run ( $self, $cb ) {
 
     say "PASSWORD: $cfg->{requirepass}";
 
+    # create and prepare unix socket dir
+    P->file->mkdir('/tmp/redis.sock') if !-d '/tmp/redis.sock';
+
+    # init log dir
+    my $log_dir = "$ENV->{LOG_DIR}";
+
     # run server
     P->pm->run_proc(
         [ 'redis-server', '--include', $self->data_dir . '/redis.conf' ],
@@ -89,7 +95,7 @@ sub default_config ( $self ) {
         tcp_backlog                 => 511,
         tcp_keepalive               => 0,
         timeout                     => 0,
-        unixsocket                  => "/tmp/redis.sock",
+        unixsocket                  => "/tmp/redis.sock/redis-6379.sock",
         unixsocketperm              => 755,
     };
 }
@@ -101,9 +107,9 @@ sub default_config ( $self ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 48                   | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
+## |    3 | 54                   | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 92                   | ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                |
+## |    3 | 98                   | ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
@@ -118,16 +124,15 @@ Pcore::Redis
 
 =head1 SYNOPSIS
 
-    docker create --name redis -v redis:/var/local/pcore-redis/data/ -p 6379:6379/tcp softvisio/redis
+    docker create --name redis -v redis:/var/local/pcore-redis/data/ -p 6379:6379/tcp softvisio/pcore-redis
 
-    # !!!WARNING!!! do not use unix sockets, config is not ready yet
-    docker create --name redis -v redis:/var/local/pcore-redis/data/ -v /tmp/redis.sock:/tmp/redis.sock -p 6379:6379/tcp softvisio/redis
+    docker create --name redis -v redis:/var/local/pcore-redis/data/ -v /tmp/redis.sock/:/tmp/redis.sock/ -p 6379:6379/tcp softvisio/pcore-redis
 
     # connect via TCP
     my $h = P->handle('redis://password@host:port?db=dbindex');
 
     # connect via unix socket
-    my $h = P->handle('redis://password@/tmp/redis.sock?db=dbindex');
+    my $h = P->handle('redis://password@/tmp/redis.sock/redis-6379.sock?db=dbindex');
 
 =head1 DESCRIPTION
 
